summaryrefslogtreecommitdiff
path: root/jstests/noPassthroughWithMongod/geo_axis_aligned.js
diff options
context:
space:
mode:
Diffstat (limited to 'jstests/noPassthroughWithMongod/geo_axis_aligned.js')
-rw-r--r--jstests/noPassthroughWithMongod/geo_axis_aligned.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/jstests/noPassthroughWithMongod/geo_axis_aligned.js b/jstests/noPassthroughWithMongod/geo_axis_aligned.js
index 0849b6b7acc..877954b0f2a 100644
--- a/jstests/noPassthroughWithMongod/geo_axis_aligned.js
+++ b/jstests/noPassthroughWithMongod/geo_axis_aligned.js
@@ -62,9 +62,9 @@ for (var b = 0; b < bits.length; b++) {
{"_id": 9, "loc": {"x": center[j][0] + radius[i], "y": center[j][1] - radius[i]}});
var res =
- t.ensureIndex({loc: "2d"}, {max: bound[j][1], min: bound[j][0], bits: bits[b]});
+ t.createIndex({loc: "2d"}, {max: bound[j][1], min: bound[j][0], bits: bits[b]});
- // ensureIndex fails when this iteration inserted coordinates that are out of bounds.
+ // createIndex fails when this iteration inserted coordinates that are out of bounds.
// These are invalid cases, so we skip them.
if (!res.ok)
continue;